Crate mesocarp

Crate mesocarp 

Modules

comms
This module provides high performance communication primitives for local multi-threaded and multi-process systems. Currently only supports a local message bus using crossbeam_queue::ArrayQueue as lock-free channel.
logging
A module for high performance simulation data loggers.
scheduling
A set of scheduling primitives with low algorithmic complexity, for high-performance time-based systems.

Structs

IoError
Wrapper type for std::io::Error

Enums

MesoError
Error type for all primitives